skins Package
=============

:mod:`skins` Package
--------------------

.. automodule:: CMFDefault.browser.skins
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`icons` Module
-------------------

.. automodule:: CMFDefault.browser.skins.icons
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ursa` Module
------------------

.. automodule:: CMFDefault.browser.skins.ursa
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    CMFDefault.browser.skins.tests

